SimpleUnc

Struct SimpleUnc 

pub struct SimpleUnc {
    pub map_to_drive: bool,
    pub skip_dunce: bool,
    pub _unused: bool,
}
Simplifies Win32 File Namespaces paths (the “\\?\” prefix) for better readability and compatibility.

SimpleUnc::default().canonicalize(path);

is a snap-in replacement of fs::canonicalize.

C:\dirZ:\x (network)
fs::canonicalize\\?\C:\dir\\?\UNC\server\share\x
SimpleUncC:\dir\\server\share\x
SimpleUnc with map_to_driveC:\dirZ:\x

Fields

map_to_drive: bool

Map to the network share drive when possible.

let path = "file.txt";
let unc = SimpleUnc { map_to_drive: true, ..Default::default() };
let canonicalized = unc.canonicalize(path)?;

If the file.txt is in a network drive, the result is Z:\dir\file.txt instead of \\server\share\dir\file.txt.

The following code tries to preserve the original form of the path.

SimpleUnc {
    map_to_drive: !path.as_os_str().as_encoded_bytes().starts_with(br"\\"),
    ..Default::default()
}.canonicalize(path)?;
skip_dunce: bool

The dunce simplification is applied by default. Set to true to skip it.

_unused: bool

It is highly recommended to always use , ..Default::default(). Otherwise builds fail when new fields are added.

This field is not used in any ways, but exists to allow using , ..Default::default() even when all other fields are specified.

Implementations

Source

impl SimpleUnc

pub fn canonicalize(&self, path: impl AsRef<Path>) -> Result<PathBuf>

Calls fs::canonicalize and simplify.

On other platforms than Windows, this is equivalent to fs::canonicalize.

pub fn simplify<'a>(&self, path: &'a Path) -> Result<Option<Cow<'a, Path>>>

Try to simplify the given path.

Returns Ok(None) if no simplification is applied, or on other platforms than Windows.

pub fn refresh() -> Result<()>

Refreshes the cached information.

pub fn display<'a>(&'a self, path: &'a Path) -> Display<'a>

Returns an object that implements Display.

Examples
let path = Path::new("file").canonicalize()?;
println!("{}", SimpleUnc::default().display(&path));